@@ -1,4 +1,4 @@
 # this file only keeps the most common & critical types/utility functions
 from .common import PathIsh, Paths, Json
-from .common import get_files
+from .common import get_files, LazyLogger
 from .cfg import make_config
