@@ -2,7 +2,7 @@
 Just a demo module for testing and documentation purposes
 '''
 
-from .core.common import Paths
+from .core import Paths
 
 from datetime import tzinfo
 import pytz
@@ -16,18 +16,13 @@ class demo(user_config):
     username: str
     timezone: tzinfo = pytz.utc
 
-
-def config() -> demo:
-    from .core.cfg import make_config
-    config = make_config(demo)
-    return config
-
-
+from .core import make_config
+config = make_config(demo)
 
 from pathlib import Path
 from typing import Sequence, Iterable
 from datetime import datetime
-from .core.common import Json, get_files
+from .core import Json, get_files
 
 @dataclass
 class Item:
@@ -40,17 +35,17 @@ class Item:
 
 
 def inputs() -> Sequence[Path]:
-    return get_files(config().data_path)
+    return get_files(config.data_path)
 
 
 import json
 def items() -> Iterable[Item]:
     for f in inputs():
-        dt = datetime.fromtimestamp(f.stat().st_mtime, tz=config().timezone)
+        dt = datetime.fromtimestamp(f.stat().st_mtime, tz=config.timezone)
         j = json.loads(f.read_text())
         for raw in j:
             yield Item(
-                username=config().username,
+                username=config.username,
                 raw=raw,
                 dt=dt,
             )
